Quelle: https://register.awmf.org/assets/guidelines/021-022l_S2k_KF_Qualitaetsanforderungen-gastrointestinale-Endoskopie_2025-01.pdf

## 4.2 Endoskopische Prozeduren bei erhöhtem Blutungsrisiko

### 4.2.1 Laborchemie vor Endoskopie

Empfehlung 2.13:

- Ein Routinescreening vor Endoskopie mit niedrigem Blutungsrisiko (INR, PTT, Blutungszeit) sollte in Abwesenheit einer klinischen Anamnese für ein Blutungsereignis, einer Risikoerkrankung oder eines klinischen Verdachtes nicht vorgenommen werden.
- Ebenso sollte keine Routinetestung bzgl Anämie, Nieren-, Leberfunktionsstörung oder anderer Serumparameter ohne eine klinische Anamnese erfolgen

Empfehlung 2.14:

- Zur Labordiagnostik vor Eingriffen mit hohem Blutungsrisiko kann aufgrund mangelnder Evidenz keine eindeutige Empfehlung abgegeben werden

Empfehlung 2.15:

- Gerrinungsdiagnostik soll bei Vorliegen von anamnestischen Faktoren und Vorerkrankungen erfolgen die auf ein erhöhtes Blutungsrisiko hinweisen sofern hier nicht bereits Befunde vorliegen
- Beinhaltet: 
  - Pos. Blutungsanamnese nach stattgehabten Eingriffen
  - Internistische Vorerkrankungen mit erhöhtem Blutungsrisiko 
    - Vaskulär Hämorrhagische Diathesen (M. Osler, Ehlers Danlos Syndrom, Marfan Syndrom)
    - Angeborene Thrombozytopathien
    - Angeborene plasmatische Gerinnungsstörungen (von-Willebrand-Syndrom, Faktor VIII o. IX Mangel
    - Erworbene Thrombozytenfunktionsstörungen / plasmatische Gerinnungsstörungen bspw. bei 
      - Lebererkrankung
      - Nierenerkrankung
      - prolongierter biliärer Obstruktion
      - prolongierter Antibiotikaeinnahme
      - malnutrition
      - myeloproliferative Erkrankungen
    - Medikamentenanamnese 
      - "ob die Einnahme von Thrombozytenaggregationshemmern oder oralen Antikoagulatien gerinnungsphysiologische Untersuchungen indiziert ist im Einzelfall zu Entscheiden.

### 4.2.2 Blutungsrisiko endoskopischer Eingriffe

Empfehlung 2.16 / Tabelle 14:

Um eine (Nutzen-)Risiko Abwägung für den Patienten treffen zu können, soll eine Einschätzung des Blutungsrisikos des jeweiligen endoskopischen Eingriffes in Eingriffe mit niedrigem Blutungsrisiko und Eingriffe mit hohem Blutungsrisiko erfolgen.

Niedriges Blutungsrisiko

- Diagnostische Endoskopie mit / ohne Biopsie 
  - Gastroskopie
  - Kolonoskopie
  - Ballnenteroskopie
  - Kapsel
- ERCP ohne EST mit /ohne Stent
- EUS ohne Feinnadelpunktion
- Enterale Stentimplantation ohne Dilatation
- APC von GI Blutungen

Hohes Blutungsrisiko

- Polypektomie
- EMR/ESD/POEM
- ERCP mit EST oder Ballondilatation
- EUS mit Feinnadelpunktion oder EUS gesteuerte interventionelle Therapie
- Ballondilatation/Bougierung
- Varizentherapie (Ligatur, Sklerosierung)
- PEG
- Diagnostische Laparoskopie mit Organbiopsie
- PTC / PTCD
- Radiofrequenzablation

### 4.2.3 Medikation mit Thrombozytenaggregationshemmern, Heparinen, (direkten) oralen Antikoagulatien

Empfehlung 2.17

Bei geplanten endoskopischen Eingriffen unter Medikation mit Thrombozytenaggregationshemmern und/oder oralen Antikoagulantien soll das individuelle Blutungsrisiko des Patienten unter Berücksichtigung des endoskopischen Eingriffes und der bestehenden Medikation gegen das individuelle Risiko für eine thrombembolische Komplikation durch ein Pausieren der Medikation abgewogen werden. Dies gilt auch für die Wiederaufnahme der Medikation. Im Einzelfall sollte das Vorgehen mit den Ärzten abgestimmt werden, die die Indikation für diese Medikation gestellt haben.

Starke Empfehlung, Empfehlung, starker Konsens